==> apache-ambari-2.7.8-src.tar.gz: apache-ambari-2.7.8-src/ambari-server/src/main/resources/stacks/BIGTOP/0.8/services/HIVE/package/scripts/mysql_server.py <==
#!/usr/bin/env python
"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

"""

import sys
from resource_management import *

from mysql_service import mysql_service

class MysqlServer(Script):

  def install(self, env):
    import params
    
    self.install_packages(env, exclude_packages=params.hive_exclude_packages)
    self.configure(env)

  def configure(self, env):
    import params
    env.set_params(params)

    mysql_service(daemon_name=params.daemon_name, action='start')

    File(params.mysql_adduser_path,
         mode=0755,
         content=StaticFile('addMysqlUser.sh')
    )

    cmd = format("bash -x {mysql_adduser_path} {daemon_name} {hive_metastore_user_name} {hive_metastore_user_passwd!p} {mysql_host[0]}")

    Execute(cmd,
            tries=3,
            try_sleep=5,
            path='/usr/sbin:/sbin:/usr/local/bin:/bin:/usr/bin'
    )

  def start(self, env):
    import params
    env.set_params(params)

    mysql_service(daemon_name=params.daemon_name, action = 'start')

  def stop(self, env):
    import params
    env.set_params(params)

    mysql_service(daemon_name=params.daemon_name, action = 'stop')

  def status(self, env):
    import status_params
    mysql_service(daemon_name=status_params.daemon_name, action = 'status')

if __name__ == "__main__":
  MysqlServer().execute()

==> apache-ambari-3.0.0-src.tar.gz: apache-ambari-3.0.0-src/ambari-server/src/main/resources/stacks/BIGTOP/3.2.0/services/HIVE/package/scripts/mysql_server.py <==
#!/usr/bin/env python3
"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

"""

# Python Imports
import sys
import os

# Local Imports
import mysql_users
from mysql_service import mysql_service
from mysql_utils import mysql_configure

# Ambari Commons & Resource Management Imports
from resource_management.libraries.script.script import Script


class MysqlServer(Script):
  def install(self, env):
    import params

    self.install_packages(env)
    self.configure(env)

  def clean(self, env):
    import params

    env.set_params(params)
    mysql_users.mysql_deluser()

  def configure(self, env):
    import params

    env.set_params(params)
    mysql_configure()

  def start(self, env, upgrade_type=None):
    import params

    env.set_params(params)
    mysql_service(action="start")

  def stop(self, env, upgrade_type=None):
    import params

    env.set_params(params)
    mysql_service(action="stop")

  def status(self, env):
    import status_params

    env.set_params(status_params)

    mysql_service(action="status")


if __name__ == "__main__":
  MysqlServer().execute()
